/**
 * This file is part of OpenMediaVault-autoshutdown.
 *
 * @license	 http://www.gnu.org/licenses/gpl.html GPL Version 3
 * @author		Marcel Beck <marcel.beck@mbeck.org>
 * @copyright Copyright (c) 2012 Marcel Beck
 *
 * OpenMediaVault is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * OpenMediaVault is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenMediaVault. If not, see <http://www.gnu.org/licenses/>.
 */
// require("js/omv/NavigationPanel.js")
// require("js/omv/data/DataProxy.js")
// require("js/omv/FormPanelExt.js")
// require("js/omv/form/PasswordField.js")
// require("js/omv/form/SharedFolderComboBox.js")
// require("js/omv/form/plugins/FieldInfo.js")

Ext.ns("OMV.Module.Services");

// Register the menu.
OMV.NavigationPanelMgr.registerMenu("services", "autoshutdown", {
	text:"Autoshutdown",
	icon:"images/autoshutdown.png"
});

/**
 * @class OMV.Module.Services.AutoshutdownSettingsPanel
 * @derived OMV.FormPanelExt
 */
OMV.Module.Services.AutoshutdownSettingsPanel = function (config) {
	var initialConfig = {
		rpcService  :"Autoshutdown",
		rpcGetMethod:"getSettings",
		rpcSetMethod:"setSettings"
	};
	Ext.apply(initialConfig, config);
	OMV.Module.Services.AutoshutdownSettingsPanel.superclass.constructor.call(
					this, initialConfig);
};
Ext.extend(OMV.Module.Services.AutoshutdownSettingsPanel, OMV.FormPanelExt, {
	getFormItems:function () {
		return [
			{
				xtype   :"fieldset",
				title   :"General settings",
				defaults:{
//				anchor: "100%",
					labelSeparator:""
				},
				items   :[
					{
						xtype     :"checkbox",
						name      :"enable",
						fieldLabel:"Enable",
						checked   :false,
						inputValue:1
					},
					{
						xtype     :"checkbox",
						name      :"debug",
						fieldLabel:"Debug",
						checked   :false,
						inputValue:1
					},
					{
						xtype     :"numberfield",
						name      :"flag",
						fieldLabel:"Flag",
						value     :6,
						plugins   :[ OMV.form.plugins.FieldInfo ],
						infoText  :"Set the number of total failures before shutdown."
					},
					{
						xtype     :"numberfield",
						name      :"sleep",
						fieldLabel:"Sleep",
						value     :180,
						plugins   :[ OMV.form.plugins.FieldInfo ],
						infoText  :"Numbers of seconds between each check/loop."
					},
					{
						xtype     :"textfield",
						name      :"range",
						fieldLabel:"Range",
						value     :"2..254",
						plugins   :[ OMV.form.plugins.FieldInfo ],
						infoText  :"Define a range of IPs which should be scanned, <br />"
										+ "via XXX.XXX.XXX.xxx last triple of IP address in a list <br />"
										+ "The following scheme is mandatory <br />"
										+ "v..v+m,w,x..x+n,y+o..y,z <br />"
										+ "define an ip range :    <start>..<end> -> the two dots are mandatory <br />"
										+ "define a single ip :   <ip> <br />"
										+ "all list entries seperated by comma ',' <br />"
										+ "Please make sure to leave 1 and 255 out of the list !"
					},
					{
						xtype     :"checkbox",
						name      :"checkclockactive",
						fieldLabel:"Check Clock",
						checked   :false,
						inputValue:1,
						plugins   :[ OMV.form.plugins.FieldInfo ],
						infoText  :"Check Clock to identify uptime."
					},
					{
						xtype     :"textfield",
						name      :"uphours",
						fieldLabel:"Up Hours",
						value     :"06..20",
						plugins   :[ OMV.form.plugins.FieldInfo ],
						infoText  :"Define a range of hours, in which the system should stay up."
					},
					{
						xtype     :"textfield",
						name      :"nsocketnumbers",
						fieldLabel:"Network Socket Ports",
						value     :"22,139,445,10000,49152",
						plugins   :[ OMV.form.plugins.FieldInfo ],
						infoText  :"Socket numbers to check for activity."
					},
					{
						xtype     :"textfield",
						name      :"loadprocnames",
						fieldLabel:"Proc Names",
						value     :"smbd,nfsd,transmission-daemon,mt-daapd",
						plugins   :[ OMV.form.plugins.FieldInfo ],
						infoText  :"Command names of processes with load dependent children."
					},
					{
						xtype     :"textfield",
						name      :"tempprocnames",
						fieldLabel:"Temp Proc Names",
						value     :"in.tftpd",
						plugins   :[ OMV.form.plugins.FieldInfo ],
						infoText  :"Command names of processes only started when active."
					},
					{
						xtype     :"checkbox",
						name      :"syslog",
						fieldLabel:"Syslog",
						checked   :true,
						inputValue:1,
						plugins   :[ OMV.form.plugins.FieldInfo ],
						infoText  :"Write to syslog."
					},
					{
						xtype     :"checkbox",
						name      :"verbose",
						fieldLabel:"Verbose",
						checked   :true,
						inputValue:1,
						plugins   :[ OMV.form.plugins.FieldInfo ],
						infoText  :"Verbose Mode."
					}
				]
			}
		];
	}
});
OMV.NavigationPanelMgr.registerPanel("services", "autoshutdown", {
	cls     :OMV.Module.Services.AutoshutdownSettingsPanel,
	title   :"Settings",
	position:10
});