<?php
/**
 * This file is part of OpenMediaVault-autoshutdown.
 *
 * @license	 http://www.gnu.org/licenses/gpl.html GPL Version 3
 * @author		Marcel Beck <marcel.beck@mbeck.org>
 * @copyright Copyright (c) 2012 Marcel Beck
 *
 * OpenMediaVault is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * any later version.
 *
 * OpenMediaVault is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenMediaVault. If not, see <http://www.gnu.org/licenses/>.
 */
require_once("openmediavault/object.inc");
require_once("openmediavault/error.inc");
require_once("openmediavault/util.inc");
require_once("openmediavault/rpc.inc");
require_once("openmediavault/notify.inc");

class AutoshutdownRpc extends OMVRpc {

	public function __construct()
	{
		$this->methodSchemata = array(
			"setSettings" => array(
				'{
				"type":"object",
				"properties":{
					"enable":{"type":"boolean"},
					"debug":{"type":"boolean"},
					"flag":{"type":"integer"},
					"sleep":{"type":"integer"},
					"range":{"type":"string"},
					"checkclockactive":{"type":"boolean"},
					"uphours":{"type":"string"},
					"nsocketnumbers":{"type":"string"},
					"loadprocnames":{"type":"string"},
					"tempprocnames":{"type":"string"},
					"syslog":{"type":"boolean"},
					"verbose":{"type":"boolean"}
				}
			}'
			),
		);
	}

	/**
	 * Get configuration object.
	 */
	function getSettings()
	{
		global $xmlConfig;
		// Check permissions
		$this->validateSession();
		if (! $this->hasRole(OMV_ROLE_ADMINISTRATOR))
		{
			throw new OMVException(OMVErrorMsg::E_RPC_SERVICE_INVALID_PERMISSION);
		}
		$this->commitSession();
		// Get configuration object
		$xpath  = "//services/autoshutdown";
		$object = $xmlConfig->get($xpath);
		if (is_null($object))
		{
			throw new OMVException(OMVErrorMsg::E_CONFIG_GET_OBJECT_FAILED,
				$xpath);
		}
		// Modify result data
		$object['enable']           = boolval($object['enable']);
		$object['debug']            = boolval($object['debug']);
		$object['flag']             = intval($object['flag']);
		$object['sleep']            = intval($object['sleep']);
		$object['checkclockactive'] = boolval($object['checkclockactive']);
		$object['syslog']           = boolval($object['syslog']);
		$object['verbose']          = boolval($object['verbose']);

		return $object;
	}

	/**
	 * Set configuration object.
	 */
	function setSettings($data)
	{
		//		$this->debug(var_export(func_get_args(), TRUE));
		global $xmlConfig;
		// Check permissions
		$this->validateSession();
		if (! $this->hasRole(OMV_ROLE_ADMINISTRATOR))
		{
			throw new OMVException(OMVErrorMsg::E_RPC_SERVICE_INVALID_PERMISSION);
		}
		$this->commitSession();
		// Validate method parameters
		$this->validateParams(__METHOD__, func_get_args());

		// Get existing configuration object
		$xpath = "//services/autoshutdown";

		// Prepare configuration data
		$object = array(
			"enable"					 => array_boolval($data, 'enable'),
			"debug"            => array_boolval($data, 'debug'),
			"flag"						 => intval($data['flag']),
			"sleep"						=> intval($data['sleep']),
			"range"						=> $data['range'],
			"checkclockactive" => array_boolval($data, 'checkclockactive'),
			"uphours"					=> $data['uphours'],
			"nsocketnumbers"	 => $data['nsocketnumbers'],
			"loadprocnames"		=> $data['loadprocnames'],
			"tempprocnames"		=> $data['tempprocnames'],
			"syslog"					 => array_boolval($data, 'syslog'),
			"verbose"					=> array_boolval($data, 'verbose'),
		);
		// Set configuration object		
		if (FALSE === $xmlConfig->replace($xpath, $object))
		{
			throw new OMVException(OMVErrorMsg::E_CONFIG_SET_OBJECT_FAILED);
		}
		// Save configuration
		if (FALSE === $xmlConfig->save())
		{
			throw new OMVException(OMVErrorMsg::E_CONFIG_SAVE_FAILED,
				$xmlConfig->getError());
		}
		// Notify configuration changes
		$dispatcher = &OMVNotifyDispatcher::getInstance();
		$dispatcher->notify(OMV_NOTIFY_MODIFY,
												"org.openmediavault.services.autoshutdown", $object);
	}
}

?>
